@@ -10,7 +10,8 @@ DEFAULT_CONFIG = {
         'use_ssl': True,
         'verify_ssl_certs': True,
         'use_proxy': False,
-        'timeout_secs': 5
+        'timeout_secs': 5,
+        'max_retries': None
     },
     'proxies': {
         'http': 'http://user:pass@host:port',
